/*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
#define RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1

// Meta data item definition version
const char* const RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const char* const RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
typedef struct MetaDataItemInfo
{
    const char*   name;
    const char*   title;
    const char*   description;
    unsigned char status;
    const char*   schema;
    const char*   example;
} MetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Angular notch filter parameters for window glass "
    "echoes\",\"title\":\"Angular Notch Filter\",\"$schema\":\"http://json-schema.o"
    "rg/draft-04/schema#\",\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\""
    "],\"type\":\"object\",\"properties\":{\"angle\":{\"items\":{\"type\":\"number\"},\"de"
    "scription\":\"Angle [deg]\",\"type\":\"array\"},\"range_mean\":{\"items\":{\"type\""
    ":\"number\"},\"description\":\"Mean range [m]\",\"type\":\"array\"},\"amplitude_m"
    "ean\":{\"items\":{\"type\":\"number\"},\"description\":\"Mean amplitude "
    "[dB]\",\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],\"ran"
    "ge_mean\":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,"
    "0.0675,0.06475],\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,"
    "2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Atmospheric parameters\",\"title\":\"Atmospheric Parameter"
    "s\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"te"
    "mperature\",\"pressure\",\"rel_humidity\",\"pressure_sl\",\"amsl\",\"group_veloc"
    "ity\",\"attenuation\",\"wavelength\"],\"type\":\"object\",\"properties\":{\"group_"
    "velocity\":{\"description\":\"Group velocity of laser beam "
    "[m/s]\",\"type\":\"number\"},\"temperature\":{\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\",\"type\":\"number\"},\"rel_humidity\":{\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\",\"type\":\"number\"},\"attenuation\":{\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\",\"type\":\"number\"},\"pressure\":{\"description\":\"Pressure along "
    "measurment path [mbar]\",\"type\":\"number\"},\"amsl\":{\"description\":\"Height"
    " above mean sea level (AMSL) "
    "[m]\",\"type\":\"number\"},\"wavelength\":{\"description\":\"Laser wavelength "
    "[nm]\",\"type\":\"number\"},\"pressure_sl\":{\"description\":\"Atmospheric "
    "pressure at sea level [mbar]\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"group_velocity\":299711000.0,\"temperature\":7,\"rel_humidity\":63,\"atten"
    "uation\":0.028125,\"pressure\":970,\"amsl\":0,\"wavelength\":1550,\"pressure_s"
    "l\":970}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Laser beam geometry details\",\"title\":\"Beam Geometry\",\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"beam_e"
    "xit_diameter\",\"beam_divergence\"],\"type\":\"object\",\"properties\":{\"beam_e"
    "xit_diameter\":{\"minimum\":0,\"exclusiveMinimum\":false,\"description\":\"Bea"
    "m width at exit aperture [m]\",\"type\":\"number\"},\"beam_divergence\":{\"min"
    "imum\":0,\"exclusiveMinimum\":false,\"description\":\"Beam divergence in far"
    " field [rad]\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"List of control object type "
    "definitions\",\"title\":\"Control Object Catalog\",\"properties\":{\"types\":{\""
    "uniqueItems\":true,\"items\":{\"oneOf\":[{\"$ref\":\"#/definitions/rectangle\"}"
    ",{\"$ref\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/definitions/chevr"
    "on\"},{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/definitions/cyl"
    "inder\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/definitions/round_c"
    "orner_cube_prism\"}],\"type\":\"object\"},\"type\":\"array\"}},\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"required\":[\"types\"],\"type\":\"objec"
    "t\",\"definitions\":{\"sphere\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{"
    "\"required\":[\"shape\",\"diameter\"],\"description\":\"sphere specific propert"
    "ies\",\"type\":\"object\",\"properties\":{\"shape\":{\"description\":\"shape ident"
    "ifier\",\"type\":\"string\",\"enum\":[\"sphere\"]},\"diameter\":{\"minimum\":0,\"exc"
    "lusiveMinimum\":true,\"description\":\"diameter in meters\",\"type\":\"number\""
    "}}}],\"description\":\"sphere\",\"type\":\"object\"},\"rectangle\":{\"allOf\":[{\"$"
    "ref\":\"#/definitions/common\"},{\"required\":[\"shape\",\"length\",\"width\"],\"d"
    "escription\":\"rectangle specific properties\",\"type\":\"object\",\"propertie"
    "s\":{\"width\":{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"width "
    "in meters\",\"type\":\"number\"},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangl"
    "e\"]},\"length\":{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"leng"
    "th in meters\",\"type\":\"number\"}}}],\"description\":\"rectangle\",\"type\":\"ob"
    "ject\"},\"chevron\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"required\""
    ":[\"shape\",\"outside_edge_length\",\"thickness\"],\"description\":\"chevron "
    "specific properties\",\"type\":\"object\",\"properties\":{\"outside_edge_lengt"
    "h\":{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"length of the "
    "two outer edges in meters\",\"type\":\"number\"},\"thickness\":{\"minimum\":0,\""
    "exclusiveMinimum\":true,\"description\":\"thickness in "
    "meters\",\"type\":\"number\"},\"shape\":{\"description\":\"shape identifier\",\"ty"
    "pe\":\"string\",\"enum\":[\"chevron\"]}}}],\"description\":\"chevron\",\"type\":\"ob"
    "ject\"},\"circular_disk\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"req"
    "uired\":[\"shape\",\"diameter\"],\"description\":\"circular disk specific prop"
    "erties\",\"type\":\"object\",\"properties\":{\"shape\":{\"description\":\"shape id"
    "entifier\",\"type\":\"string\",\"enum\":[\"circular_disk\"]},\"diameter\":{\"minim"
    "um\":0,\"exclusiveMinimum\":true,\"description\":\"diameter in "
    "meters\",\"type\":\"number\"},\"offset\":{\"description\":\"offset in meters, "
    "e.g. reflector constant "
    "(optional)\",\"type\":\"number\"}}}],\"description\":\"circular disk\",\"type\":\""
    "object\"},\"checkerboard2x2\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{"
    "\"required\":[\"shape\",\"square_length\"],\"description\":\"checkerboard "
    "specific properties\",\"type\":\"object\",\"properties\":{\"shape\":{\"descripti"
    "on\":\"shape identifier\",\"type\":\"string\",\"enum\":[\"checkerboard2x2\"]},\"sq"
    "uare_length\":{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"lengt"
    "h of a square of the checkerboard in "
    "meters\",\"type\":\"number\"}}}],\"description\":\"checkerboard 2 by 2\",\"type\""
    ":\"object\"},\"cylinder\":{\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"requ"
    "ired\":[\"shape\",\"diameter\",\"height\"],\"description\":\"cylinder specific p"
    "roperties\",\"type\":\"object\",\"properties\":{\"shape\":{\"description\":\"shape"
    " identifier\",\"type\":\"string\",\"enum\":[\"cylinder\"]},\"diameter\":{\"minimum"
    "\":0,\"exclusiveMinimum\":true,\"description\":\"diameter in meters\",\"type\":"
    "\"number\"},\"height\":{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":"
    "\"height in meters\",\"type\":\"number\"}}}],\"description\":\"cylinder\",\"type\""
    ":\"object\"},\"common\":{\"required\":[\"name\",\"shape\"],\"description\":\"common"
    " object properties\",\"type\":\"object\",\"properties\":{\"surface_type\":{\"des"
    "cription\":\"surface material type\",\"type\":\"string\",\"enum\":[\"retro_refle"
    "ctive_foil\",\"diffuse\"]},\"shape\":{\"description\":\"shape identifier\",\"typ"
    "e\":\"string\",\"enum\":[\"rectangle\",\"checkerboard2x2\",\"chevron\",\"circular_"
    "disk\",\"cylinder\",\"sphere\",\"round_corner_cube_prism\"]},\"name\":{\"minLeng"
    "th\":3,\"description\":\"unique type "
    "identifier\",\"type\":\"string\"},\"description\":{\"description\":\"string "
    "describing the object\",\"type\":\"string\"}}},\"round_corner_cube_prism\":{\""
    "allOf\":[{\"$ref\":\"#/definitions/common\"},{\"required\":[\"shape\",\"diameter"
    "\"],\"description\":\"round corner cube prism specific properties\",\"type\":"
    "\"object\",\"properties\":{\"shape\":{\"description\":\"shape identifier\",\"type"
    "\":\"string\",\"enum\":[\"round_corner_cube_prism\"]},\"diameter\":{\"minimum\":0"
    ",\"exclusiveMinimum\":true,\"description\":\"diameter in "
    "meters\",\"type\":\"number\"},\"offset\":{\"description\":\"offset in meters, "
    "e.g. reflector constant "
    "(optional)\",\"type\":\"number\"}}}],\"description\":\"round corner cube "
    "prism\",\"type\":\"object\"}}}"
    ,
    /* example: */
    "{\"types\":[{\"width\":0.3,\"shape\":\"rectangle\",\"name\":\"Rectangle "
    "60x30\",\"description\":\"Rectangle (60cm x 30cm)\",\"length\":0.6},{\"width\":"
    "0.4,\"shape\":\"rectangle\",\"name\":\"Rectangle "
    "80x40\",\"description\":\"Rectangle (80cm x 40cm)\",\"length\":0.8},{\"shape\":"
    "\"checkerboard2x2\",\"name\":\"Checkerboard2x2 "
    "30\",\"description\":\"Checkerboard (square length: 30cm)\",\"square_length\""
    ":0.3},{\"shape\":\"checkerboard2x2\",\"name\":\"Checkerboard2x2 "
    "50\",\"description\":\"Checkerboard (square length: 50cm)\",\"square_length\""
    ":0.5},{\"outside_edge_length\":0.6096,\"thickness\":0.1016,\"shape\":\"chevro"
    "n\",\"name\":\"Chevron 24''/4''\",\"description\":\"Chevron (a=24''; b=4'')\"},"
    "{\"surface_type\":\"diffuse\",\"shape\":\"circular_disk\",\"name\":\"Circular "
    "Disk 50\",\"diameter\":0.5,\"description\":\" Circular Disk (diameter: "
    "50cm)\"},{\"offset\":0.0,\"description\":\"flat circular reflector from "
    "retro-reflective "
    "foil\",\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL flat "
    "reflector 50 mm\",\"diameter\":0.05,\"shape\":\"circular_disk\"},{\"offset\":0."
    "0,\"description\":\"flat circular reflector from retro-reflective "
    "foil\",\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL flat "
    "reflector 100 mm\",\"diameter\":0.1,\"shape\":\"circular_disk\"},{\"offset\":0."
    "0,\"description\":\"flat circular reflector from retro-reflective "
    "foil\",\"surface_type\":\"retro_reflective_foil\",\"name\":\"RIEGL flat "
    "reflector 150 mm\",\"diameter\":0.15,\"shape\":\"circular_disk\"},{\"shape\":\"c"
    "ylinder\",\"description\":\"cylindrical reflector from retro-reflective fo"
    "il\",\"surface_type\":\"retro_reflective_foil\",\"height\":0.05,\"name\":\"RIEGL"
    " cylindrical reflector 50 "
    "mm\",\"diameter\":0.05},{\"shape\":\"cylinder\",\"description\":\"cylindrical "
    "reflector from retro-reflective foil\",\"surface_type\":\"retro_reflective"
    "_foil\",\"height\":0.1,\"name\":\"RIEGL cylindrical reflector 100 "
    "mm\",\"diameter\":0.1},{\"shape\":\"sphere\",\"name\":\"Sphere 200 "
    "mm\",\"diameter\":0.2,\"description\":\"Sphere (diameter: 200 "
    "mm)\"},{\"offset\":0.0,\"shape\":\"round_corner_cube_prism\",\"name\":\"Corner "
    "Cube Prism 50 mm\",\"diameter\":0.05,\"description\":\"round corner cube "
    "prism\"}],\"comments\":[\"This file contains a list of control object "
    "types (aka. 'catalog').\",\"Each type is described by an object,\",\"which"
    " must contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"De"
    "tails about the control object reference file\",\"title\":\"Control Object"
    " Reference file\",\"type\":\"object\",\"properties\":{\"reference_file\":{\"requ"
    "ired\":[\"file_uuid\",\"file_path\"],\"description\":\"Reference to a control "
    "object "
    "file\",\"type\":\"object\",\"properties\":{\"file_path\":{\"description\":\"Path "
    "of the control object file relative to referring "
    "file\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"Control object "
    "file's Universally Unique Identifier (RFC 4122)\",\"type\":\"string\"}}}}}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoi"
    "nts.cpx\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Detection probability as a function of "
    "amplitude\",\"title\":\"Detection Probability\",\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"required\":[\"amplitude\",\"detection_probabilit"
    "y\"],\"type\":\"object\",\"properties\":{\"amplitude\":{\"items\":{\"type\":\"number"
    "\"},\"description\":\"Amplitude [dB]\",\"type\":\"array\"},\"detection_probabili"
    "ty\":{\"items\":{\"type\":\"number\"},\"description\":\"Detection probability "
    "[0..1]\",\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],\"detection"
    "_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the device used to acquire the point "
    "cloud\",\"title\":\"Device Information\",\"$schema\":\"http://json-schema.org/"
    "draft-04/schema#\",\"required\":[\"device_type\",\"serial_number\"],\"type\":\"o"
    "bject\",\"properties\":{\"device_name\":{\"description\":\"Optional device "
    "name (e.g. 'Scanner 1' for multi-scanner systems)\",\"type\":\"string\"},\"c"
    "hannel_number\":{\"minimum\":0,\"exclusiveMinimum\":false,\"description\":\"La"
    "ser channel number (not defined or 0: single channel "
    "device)\",\"type\":\"integer\"},\"channel_text\":{\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\",\"type\":\"string\"},\"device_type\":{\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\",\"type\":\"string\"},\"device_build\":{\"description\":\"Device build"
    " variant\",\"type\":\"string\"},\"serial_number\":{\"description\":\"Device "
    "serial number (e.g. S2221234)\",\"type\":\"string\"}}}"
    ,
    /* example: */
    "{\"device_name\":\"Scanner 1\",\"channel_number\":0,\"channel_text\":\"\",\"devic"
    "e_type\":\"VZ-400i\",\"device_build\":\"\",\"serial_number\":\"S2221234\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Scanner device geometry details\",\"title\":\"Device Geome"
    "try\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\""
    "primary\"],\"type\":\"object\",\"properties\":{\"primary\":{\"required\":[\"ID\",\"c"
    "ontent\"],\"description\":\"Primary device geometry structure (mandatory)\""
    ",\"type\":\"object\",\"properties\":{\"content\":{\"items\":{\"type\":\"number\"},\"d"
    "escription\":\"Internal calibration values\",\"type\":\"array\"},\"ID\":{\"items"
    "\":{\"type\":\"integer\"},\"maxItems\":2,\"description\":\"Structure "
    "identifier\",\"type\":\"array\",\"minItems\":2}}},\"amu\":{\"description\":\"Angle"
    " Measurement Unit\",\"type\":\"object\",\"properties\":{\"frameCC\":{\"minimum\":"
    "0,\"exclusiveMinimum\":false,\"description\":\"Frame Circle Count (number "
    "of LSBs per full rotation about frame axis)\",\"type\":\"number\"},\"lineCC\""
    ":{\"minimum\":0,\"exclusiveMinimum\":false,\"description\":\"Line Circle "
    "Count (number of LSBs per full rotation about line axis)\",\"type\":\"numb"
    "er\"}}},\"secondary\":{\"required\":[\"ID\",\"content\"],\"description\":\"Additio"
    "nal device geometry structure (optional)\",\"type\":\"object\",\"properties\""
    ":{\"content\":{\"items\":{\"type\":\"number\"},\"description\":\"Internal "
    "calibration values\",\"type\":\"array\"},\"ID\":{\"items\":{\"type\":\"integer\"},\""
    "maxItems\":2,\"description\":\"Structure "
    "identifier\",\"type\":\"array\",\"minItems\":2}}}}}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[4,0]},\"amu\":{\"frameCC\":124000,\"lineCC\""
    ":124000},\"secondary\":{\"content\":[0],\"ID\":[91,0]}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Scanner passive channel device geometry "
    "details\",\"title\":\"Device Geometry Passive Channel\",\"$schema\":\"http://j"
    "son-schema.org/draft-04/schema#\",\"required\":[\"primary\"],\"type\":\"object"
    "\",\"properties\":{\"primary\":{\"required\":[\"ID\",\"content\"],\"description\":\""
    "Primary device geometry structure (mandatory)\",\"type\":\"object\",\"proper"
    "ties\":{\"content\":{\"items\":{\"type\":\"number\"},\"description\":\"Internal "
    "calibration values\",\"type\":\"array\"},\"ID\":{\"items\":{\"type\":\"integer\"},\""
    "maxItems\":2,\"description\":\"Structure "
    "identifier\",\"type\":\"array\",\"minItems\":2}}}}}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Li"
    "mits of the measured values output by the device. The limits depend on"
    " the device type, measurement program and/or scan "
    "pattern.\",\"title\":\"Device Output Limits\",\"type\":\"object\",\"properties\":"
    "{\"deviation_maximum\":{\"description\":\"Maximum possible pulse shape devi"
    "ation.\",\"type\":\"number\"},\"reflectance_minimum\":{\"description\":\"Minimum"
    " possible reflectance in "
    "dB.\",\"type\":\"number\"},\"mta_zone_count_maximum\":{\"description\":\"Maximum"
    " number of MTA "
    "zones.\",\"type\":\"number\"},\"amplitude_maximum\":{\"description\":\"Maximum "
    "possible amplitude in "
    "dB.\",\"type\":\"number\"},\"amplitude_minimum\":{\"description\":\"Minimum "
    "possible amplitude in "
    "dB.\",\"type\":\"number\"},\"reflectance_maximum\":{\"description\":\"Maximum "
    "possible reflectance in dB.\",\"type\":\"number\"},\"background_radiation_ma"
    "ximum\":{\"description\":\"Maximum possible background radiation.\",\"type\":"
    "\"number\"},\"echo_count_maximum\":{\"description\":\"Maximum number of "
    "echoes a laser shot can have.\",\"type\":\"number\"},\"background_radiation_"
    "minimum\":{\"description\":\"Minimum possible background "
    "radiation.\",\"type\":\"number\"},\"range_minimum\":{\"description\":\"Minimum "
    "possible range in "
    "meters.\",\"type\":\"number\"},\"deviation_minimum\":{\"description\":\"Minimum "
    "possible pulse shape "
    "deviation.\",\"type\":\"number\"},\"range_maximum\":{\"description\":\"Maximum "
    "possible range in meters.\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"deviation_maximum\":32767,\"background_radiation_maximum\":0,\"backgroun"
    "d_radiation_minimum\":0,\"range_minimum\":2.9,\"mta_zone_count_maximum\":7,"
    "\"reflectance_minimum\":-100.0,\"deviation_minimum\":-1,\"amplitude_maximum"
    "\":100.0,\"range_maximum\":10000.0,\"amplitude_minimum\":0.0,\"reflectance_m"
    "aximum\":100.0}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"items\":{\"required\":[\"device_type\",\"serial_number\"],\"type\":\"object\",\""
    "properties\":{\"signed\":{\"description\":\"Flag that is set when the "
    "original 'riegl.device' entry in the source file was correctly "
    "signed.\",\"type\":\"boolean\"},\"device_name\":{\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner systems)\",\"type\":\"stri"
    "ng\"},\"channel_number\":{\"minimum\":0,\"exclusiveMinimum\":false,\"descripti"
    "on\":\"Laser channel number (not defined or 0: single channel "
    "device)\",\"type\":\"integer\"},\"channel_text\":{\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\",\"type\":\"string\"},\"device_type\":{\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\",\"type\":\"string\"},\"device_build\":{\"description\":\"Device build"
    " variant\",\"type\":\"string\"},\"serial_number\":{\"description\":\"Device "
    "serial number (e.g. S2221234)\",\"type\":\"string\"}}},\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"description\":\"Details about the "
    "devices used to acquire the point cloud (e.g. when merging point "
    "clouds of different devices)\",\"title\":\"Devices "
    "Information\",\"type\":\"array\"}"
    ,
    /* example: */
    "[{\"signed\":false,\"device_name\":\"Scanner 1\",\"channel_number\":0,\"channel"
    "_text\":\"\",\"device_type\":\"VZ-400i\",\"device_build\":\"\",\"serial_number\":\"S"
    "2221234\"},{\"signed\":true,\"device_name\":\"Scanner 2\",\"channel_number\":1,"
    "\"channel_text\":\"\",\"device_type\":\"VQ-1560i-DW\",\"device_build\":\"\",\"seria"
    "l_number\":\"S2222680\"},{\"signed\":true,\"device_name\":\"Scanner 3\",\"channe"
    "l_number\":2,\"channel_text\":\"\",\"device_type\":\"VQ-1560i-DW\",\"device_buil"
    "d\":\"\",\"serial_number\":\"S2222680\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Dy"
    "ntrig\",\"title\":\"Dyntrig\",\"properties\":{\"post\":{\"required\":[\"nc\",\"a\"],\""
    "description\":\"Dyntrig post values\",\"type\":\"object\",\"properties\":{\"a\":{"
    "\"maxItems\":2080,\"description\":\"...\",\"items\":{\"type\":\"number\"},\"type\":\""
    "array\",\"minItems\":1},\"nc\":{\"description\":\"Number of entries\",\"minimum\""
    ":0,\"type\":\"integer\",\"maximum\":255}}},\"offset\":{\"description\":\"Offset "
    "in units of dB, for calculation of "
    "line\",\"type\":\"number\"},\"scale\":{\"description\":\"Scale in units of dB, "
    "for calculation of line: line number N=(amplitude-offset)/scale\",\"type"
    "\":\"number\"},\"pre\":{\"required\":[\"nc\",\"a\"],\"description\":\"Dyntrig pre va"
    "lues\",\"type\":\"object\",\"properties\":{\"a\":{\"maxItems\":2080,\"description\""
    ":\"...\",\"items\":{\"type\":\"number\"},\"type\":\"array\",\"minItems\":1},\"nc\":{\"d"
    "escription\":\"Number of entries\",\"minimum\":0,\"type\":\"integer\",\"maximum\""
    ":255}}},\"tab\":{\"maxItems\":128,\"description\":\"...\",\"items\":{\"required\":"
    "[\"thra1\",\"del1\",\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"description\":\"...\",\"typ"
    "e\":\"object\",\"properties\":{\"del1\":{\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of "
    "m\",\"type\":\"number\"},\"thra2\":{\"description\":\"Pre-trigger threshold in "
    "units of dB\",\"type\":\"number\"},\"del2\":{\"description\":\"Length of "
    "constant pre-trigger threshold elevation in units of "
    "m\",\"type\":\"number\"},\"dec1\":{\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of "
    "dB/m\",\"type\":\"number\"},\"thra1\":{\"description\":\"Post-trigger threshold "
    "in units of dB\",\"type\":\"number\"},\"dec2\":{\"description\":\"Rise of "
    "pre-trigger threshold after del2 in units of "
    "dB/m\",\"type\":\"number\"}}},\"type\":\"array\",\"minItems\":1}}}"
    ,
    /* example: */
    "{\"post\":{\"a\":[78,86,126,134,31],\"nc\":128},\"offset\":0.0,\"scale\":1.0,\"pr"
    "e\":{\"a\":[78,86,126,134,31],\"nc\":128},\"tab\":[{\"del1\":0.0,\"thra2\":0.0,\"d"
    "el2\":0.0,\"dec1\":0.0,\"thra1\":0.0,\"dec2\":0.0}]}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about echo files\",\"title\":\"Echo Information\",\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"echo_f"
    "ile\"],\"type\":\"object\",\"properties\":{\"echo_file\":{\"required\":[\"file_ext"
    "ension\"],\"type\":\"object\",\"properties\":{\"file_uuid\":{\"description\":\"Fil"
    "e's Universally Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Echo file "
    "extension, without the leading dot\",\"type\":\"string\"}}}}}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"description\":\"Details for exponential "
    "decomposition of full waveform data\",\"title\":\"Exponential Decompositio"
    "n\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\""
    ",\"definitions\":{\"channel\":{\"required\":[\"delay\",\"scale\",\"parameter\"],\"t"
    "ype\":\"object\",\"properties\":{\"parameter\":{\"required\":[\"A\",\"B\",\"gamma\",\""
    "omega\"],\"description\":\"parameters of the syswave exponential sum\",\"typ"
    "e\":\"object\",\"properties\":{\"omega\":{\"items\":{\"type\":\"number\"},\"descript"
    "ion\":\"angular frequency in Hz\",\"type\":\"array\"},\"B\":{\"items\":{\"type\":\"n"
    "umber\"},\"description\":\"imaginary part of amplitude factor in units of "
    "full-scale\",\"type\":\"array\"},\"gamma\":{\"items\":{\"type\":\"number\"},\"descri"
    "ption\":\"decay in 1/second\",\"type\":\"array\"},\"A\":{\"items\":{\"type\":\"numbe"
    "r\"},\"description\":\"real part of amplitude factor in units of "
    "full-scale\",\"type\":\"array\"}}},\"scale\":{\"description\":\"amplitude "
    "calibration\",\"type\":\"number\"},\"delay\":{\"description\":\"delay "
    "calibration in "
    "seconds\",\"type\":\"number\"},\"a_lin\":{\"description\":\"relative linear "
    "amplitude range [0..1]\",\"maximum\":1,\"exclusiveMinimum\":false,\"minimum\""
    ":0,\"type\":\"number\",\"exclusiveMaximum\":false}}}},\"patternProperties\":{\""
    "^[0-9]+$\":{\"description\":\"one field per channel, field name is channel"
    " index\",\"$ref\":\"#/definitions/channel\"}}}"
    ,
    /* example: */
    "{\"1\":{\"parameter\":{\"omega\":[352020896.0,3647927552.0,-1977987072.0],\"B"
    "\":[-3.9,0.0,-0.3],\"gamma\":[-1094726528.0,-769562752.0,-848000064.0],\"A"
    "\":[0.9,0.3,-1.3]},\"scale\":1.0,\"delay\":3.5e-09,\"a_lin\":0.9},\"0\":{\"param"
    "eter\":{\"omega\":[352020896.0,3647927552.0,-1977987072.0],\"B\":[-3.981303"
    "2150268555,0.08622030913829803,-0.3152860999107361],\"gamma\":[-10947265"
    "28.0,-769562752.0,-848000064.0],\"A\":[0.9772450923919678,0.335433512926"
    "1017,-1.312678575515747]},\"scale\":1.0,\"delay\":3.783458418887631e-09,\"a"
    "_lin\":0.27}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"riegl.gaussian_decomposition contains information "
    "relevant for extracting calibrated amplitudes and calibrated ranges "
    "from a Gaussian decomposition of full waveform data. This information "
    "is contained in a table with five columns. Two columns are to be used "
    "as input: amplitude_lsb_low_power and amplitude_lsb_high_power. The "
    "other three columns provide the outputs. Amplitude_db gives the "
    "calibrated amplitude in the optical regime in decibels. The range "
    "offset columns provide additive range offsets, given in units of "
    "seconds, for each channel.\",\"title\":\"Gaussian Decomposition\",\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"amplitude_lsb_"
    "low_power\",\"amplitude_lsb_high_power\",\"amplitude_db\",\"range_offset_sec"
    "_low_power\",\"range_offset_sec_high_power\"],\"type\":\"object\",\"properties"
    "\":{\"range_offset_sec_high_power\":{\"items\":{\"type\":\"number\"},\"type\":\"ar"
    "ray\"},\"amplitude_lsb_high_power\":{\"items\":{\"type\":\"number\"},\"type\":\"ar"
    "ray\"},\"range_offset_sec_low_power\":{\"items\":{\"type\":\"number\"},\"type\":\""
    "array\"},\"amplitude_lsb_low_power\":{\"items\":{\"type\":\"number\"},\"type\":\"a"
    "rray\"},\"amplitude_db\":{\"items\":{\"type\":\"number\"},\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"range_offset_sec_high_power\":[],\"amplitude_lsb_high_power\":[],\"range"
    "_offset_sec_low_power\":[],\"amplitude_lsb_low_power\":[],\"amplitude_db\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Po"
    "int cloud georeferencing information\",\"title\":\"Geo "
    "Tag\",\"type\":\"object\",\"properties\":{\"crs\":{\"description\":\"Global "
    "Coordinate Reference System. Please note that only 3D Cartesian "
    "Coordinate Systems are allowed.\",\"type\":\"object\",\"properties\":{\"epsg\":"
    "{\"minimum\":0,\"description\":\"EPSG "
    "code\",\"type\":\"integer\"},\"name\":{\"description\":\"Coordinate reference "
    "system name\",\"type\":\"string\"},\"wkt\":{\"description\":\"\\\"Well-Known "
    "Text\\\" string, OGC WKT dialect (see http://www.opengeospatial.org/stan"
    "dards/wkt-crs)\",\"type\":\"string\"}}},\"pose\":{\"items\":{\"items\":{\"descript"
    "ion\":\"columns\",\"type\":\"number\"},\"maxItems\":4,\"description\":\"rows\",\"typ"
    "e\":\"array\",\"minItems\":4},\"maxItems\":4,\"description\":\"Coordinate "
    "Transformation Matrix to transform from File Coordinate System to "
    "Global Coordinate Reference System. 4x4 matrix stored as two "
    "dimensional array, row major order.\",\"type\":\"array\",\"minItems\":4}}}"
    ,
    /* example: */
    "{\"crs\":{\"epsg\":4978,\"name\":\"WGS84 Geocentric\",\"wkt\":\"GEOCCS[\\\"WGS84 Ge"
    "ocentric\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.25722356"
    "3,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\"
    "\"Greenwich\\\",0.0000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"M"
    "eter\\\",1.00000000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\""
    ",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\""
    "]]\"},\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196"
    "],[0.0,0.0,0.0,1.0]]}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"exclusiveMinimum"
    "\":true,\"description\":\"Geometric scale factor applied to point "
    "coordinates\",\"type\":\"number\",\"minimum\":0}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Pa"
    "rameters used for georeferencing of the point "
    "cloud\",\"title\":\"Georeferencing Parameters\",\"type\":\"object\",\"properties"
    "\":{\"trajectory_offsets\":{\"description\":\"Correction offsets applied to "
    "the trajectory data\",\"type\":\"object\",\"properties\":{\"offset_yaw\":{\"desc"
    "ription\":\"[deg]\",\"type\":\"number\"},\"version\":{\"description\":\"Meaning of"
    " offset values and how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\",\"type\":\"integer\"},\"offset_pitch\":{\"description\":\"[d"
    "eg]\",\"type\":\"number\"},\"offset_east\":{\"description\":\"[m]\",\"type\":\"numbe"
    "r\"},\"offset_north\":{\"description\":\"[m]\",\"type\":\"number\"},\"offset_heigh"
    "t\":{\"description\":\"[m]\",\"type\":\"number\"},\"offset_roll\":{\"description\":"
    "\"[deg]\",\"type\":\"number\"},\"offset_time\":{\"description\":\"[s]\",\"type\":\"nu"
    "mber\"}}},\"socs_to_body_matrix\":{\"items\":{\"items\":{\"description\":\"colum"
    "ns\",\"type\":\"number\"},\"maxItems\":4,\"description\":\"rows\",\"type\":\"array\","
    "\"minItems\":4},\"maxItems\":4,\"description\":\"Coordinate Transformation "
    "Matrix to transform from Scanner's Own Coordinate System to Body "
    "Coordinate System. 4x4 matrix stored as two dimensional array, row "
    "major order.\",\"type\":\"array\",\"minItems\":4},\"body_coordinate_system_typ"
    "e\":{\"description\":\"BODY coordinate frame (NED: North-East-Down, ENU: "
    "East-North-Up), default: NED\",\"type\":\"string\",\"enum\":[\"NED\",\"ENU\"]},\"s"
    "ocs_to_rocs_matrix\":{\"items\":{\"items\":{\"description\":\"columns\",\"type\":"
    "\"number\"},\"maxItems\":4,\"description\":\"rows\",\"type\":\"array\",\"minItems\":"
    "4},\"maxItems\":4,\"description\":\"Coordinate Transformation Matrix to "
    "transform from Scanner's Own Coordinate System to Record Coordinate "
    "System. 4x4 matrix stored as two dimensional array, row major order.\","
    "\"type\":\"array\",\"minItems\":4},\"trajectory_file\":{\"required\":[\"file_exte"
    "nsion\"],\"description\":\"Trajectory data used for georeferencing of the "
    "point cloud\",\"type\":\"object\",\"properties\":{\"file_uuid\":{\"description\":"
    "\"File's Universally Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Trajectory "
    "file extension, without the leading dot\",\"type\":\"string\"}}}}}"
    ,
    /* example: */
    "{\"trajectory_offsets\":{\"offset_yaw\":-0.45,\"version\":0,\"offset_pitch\":0"
    ".01,\"offset_east\":0.15,\"offset_north\":0.07,\"offset_height\":-0.2,\"offse"
    "t_roll\":0.03,\"offset_time\":18.007},\"socs_to_body_matrix\":[[-0.26982777"
    "6749716,-0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-"
    "0.20260517250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.75086"
    "84796801,0.0],[0.0,0.0,0.0,1.0]],\"body_coordinate_system_type\":\"NED\",\""
    "trajectory_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\""
    "file_extension\":\"pofx\"}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"description\":\"Map of item "
    "names\",\"title\":\"Item Names\",\"$schema\":\"http://json-schema.org/draft-04"
    "/schema#\",\"type\":\"object\",\"patternProperties\":{\"^-?[0-9]+$\":{\"descript"
    "ion\":\"One field per item, field name is item id, field value is item "
    "name\",\"type\":\"string\"}}}"
    ,
    /* example: */
    "{\"2\":\"Name of item with id 2\",\"1\":\"Name of item with id 1\",\"-1\":\"Name "
    "of item with id -1\",\"47\":\"Name of item with id 47\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"description\":\"License keys for software"
    " features\",\"title\":\"Software License Keys\",\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"type\":\"object\",\"patternProperties\":{\"^.*$\":{"
    "\"items\":{\"description\":\"License key (example: '46AE032A - 39882AC4 - "
    "9EC0A184 - 6F163D73')\",\"type\":\"string\"},\"description\":\"Each field of "
    "the object represents a feature and holds a list of license keys, "
    "where the field name is the feature "
    "name.\",\"type\":\"array\",\"minItems\":1}}}"
    ,
    /* example: */
    "{\"Full Waveform Analysis Topography with GPU support\":[\"8AB44126 - "
    "23B92250 - 16E2689F - 34EF7E7B\"],\"MTA resolution\":[\"468E020A - "
    "39A922E4 - B681A184 - 673E3D72\"],\"Full Waveform Analysis "
    "Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA - "
    "8D2ED557\"],\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Pa"
    "rameters for MTA processing\",\"title\":\"MTA Settings\",\"type\":\"object\",\"p"
    "roperties\":{\"zone_count\":{\"minimum\":0,\"description\":\"Maximum number of"
    " MTA zones.\",\"type\":\"integer\",\"maximum\":255},\"zone_width\":{\"minimum\":0"
    ",\"description\":\"Width of a MTA zone in meter.\",\"type\":\"number\"},\"modul"
    "ation_depth\":{\"minimum\":0,\"description\":\"Depth of pulse position "
    "modulation in meter.\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"zone_count\":23,\"zone_width\":149.896225,\"modulation_depth\":9.368514}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Lookup table for range correction based on raw "
    "range\",\"title\":\"Near Range Correction Table\",\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"required\":[\"delta\",\"content\"],\"type\":\"obje"
    "ct\",\"properties\":{\"delta\":{\"description\":\"Delta between table entries "
    "[m], first entry is at range = 0 m\",\"type\":\"number\"},\"content\":{\"items"
    "\":{\"type\":\"number\"},\"maxItems\":2000,\"description\":\"Correction value "
    "[m] to be added to the raw range\",\"type\":\"array\",\"minItems\":1}}}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Standard deviation for range and amplitude as a "
    "function of amplitude\",\"title\":\"Noise Estimates\",\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"required\":[\"amplitude\",\"range_sigma\",\""
    "amplitude_sigma\"],\"type\":\"object\",\"properties\":{\"amplitude\":{\"items\":{"
    "\"type\":\"number\"},\"description\":\"Amplitude [dB]\",\"type\":\"array\"},\"ampli"
    "tude_sigma\":{\"items\":{\"type\":\"number\"},\"description\":\"Sigma amplitude "
    "[dB]\",\"type\":\"array\"},\"range_sigma\":{\"items\":{\"type\":\"number\"},\"descri"
    "ption\":\"Sigma range [m]\",\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],\"amplitude"
    "_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.432,0.39,0.3"
    "54],\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.0"
    "18,0.016,0.014]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Notch filter parameters for window glass "
    "echoes\",\"title\":\"Notch Filter\",\"$schema\":\"http://json-schema.org/draft"
    "-04/schema#\",\"required\":[\"range_minimum\",\"range_maximum\",\"amplitude_ma"
    "ximum\"],\"type\":\"object\",\"properties\":{\"amplitude_maximum\":{\"descriptio"
    "n\":\"Maximum amplitude [dB]\",\"minimum\":0,\"type\":\"number\"},\"range_maximu"
    "m\":{\"description\":\"Maximum range "
    "[m]\",\"type\":\"number\"},\"range_minimum\":{\"description\":\"Minimum range "
    "[m]\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"amplitude_maximum\":18.0,\"range_maximum\":0.2,\"range_minimum\":-0.5}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the pixels contained in the "
    "file\",\"title\":\"Pixel "
    "Information\",\"properties\":{\"size_llcs\":{\"description\":\"Size of pixels "
    "in a locally levelled cartesian coordinate system (xy). This is only "
    "used for pixels based on a map projection.\",\"$ref\":\"#/definitions/pixe"
    "l_size\"},\"size\":{\"description\":\"Size of pixels in file coordinate syst"
    "em.\",\"$ref\":\"#/definitions/pixel_size\"}},\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"required\":[\"size\"],\"type\":\"object\",\"definition"
    "s\":{\"pixel_size\":{\"items\":{\"minimum\":0,\"description\":\"Length of pixel "
    "edge [m].\",\"type\":\"number\"},\"maxItems\":2,\"description\":\"Size of "
    "pixels.\",\"type\":\"array\",\"minItems\":2}}}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303],\"size\":[0.5971642"
    "834779395,0.5971642834779395]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about the plane patch matching "
    "process\",\"title\":\"Plane Patch Matching\",\"properties\":{\"plane_patch_fil"
    "e_two\":{\"description\":\"Reference to the plane patch file two\",\"$ref\":\""
    "#/definitions/file_reference\"},\"plane_patch_file_one\":{\"description\":\""
    "Reference to the plane patch file one\",\"$ref\":\"#/definitions/file_refe"
    "rence\"}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required"
    "\":[\"plane_patch_file_one\",\"plane_patch_file_two\"],\"type\":\"object\",\"def"
    "initions\":{\"file_reference\":{\"required\":[\"file_uuid\",\"file_path\"],\"des"
    "cription\":\"Reference to a plane patch "
    "file\",\"type\":\"object\",\"properties\":{\"file_path\":{\"description\":\"Path "
    "of the plane patch file relative to the match "
    "file\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"Plane patch file's "
    "Universally Unique Identifier (RFC 4122)\",\"type\":\"string\"}}}}}"
    ,
    /* example: */
    "{\"plane_patch_file_two\":{\"file_path\":\"project.ptch\",\"file_uuid\":\"fa47d"
    "509-a64e-49ce-8b14-ff3130fbefa9\"},\"plane_patch_file_one\":{\"file_path\":"
    "\"Record009_Line001/191025_121410_Scanner_1.ptch\",\"file_uuid\":\"810f5d57"
    "-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"St"
    "atistics about plane patches found by plane patch "
    "extractor\",\"title\":\"Plane Patch Statistics\",\"type\":\"object\",\"propertie"
    "s\":{\"total_area\":{\"description\":\"sum of all plane patch areas [m\\u00b2"
    "]\",\"type\":\"number\"},\"total_horizontal_area\":{\"description\":\"sum of all"
    " plane patch areas projected to horizontal plane "
    "[m\\u00b2]\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"total_area\":14007.965,\"total_horizontal_area\":13954.601}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Settings and classes for plane slope "
    "classification\",\"title\":\"Plane Slope Class "
    "Info\",\"properties\":{\"classes\":{\"description\":\"Class definition "
    "table\",\"patternProperties\":{\"^[0-9]+$\":{\"description\":\"one field per "
    "class, field name is class number, field value is class name\",\"type\":\""
    "string\"}},\"type\":\"object\",\"additionalProperties\":false},\"settings\":{\"o"
    "neOf\":[{\"$ref\":\"#/definitions/method-1\"},{\"$ref\":\"#/definitions/method"
    "-2\"}],\"description\":\"Classification settings, details see "
    "documentation of rdbplanes\",\"type\":\"object\"}},\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\",\"required\":[\"settings\",\"classes\"],\"type\":\""
    "object\",\"definitions\":{\"method-2\":{\"required\":[\"plane_classification_m"
    "ethod\",\"sloping_plane_classes_minimum_angle\",\"sloping_plane_classes_ma"
    "ximum_angle\"],\"description\":\"Classification method 2\",\"type\":\"object\","
    "\"properties\":{\"plane_classification_method\":{\"minimum\":2,\"description\""
    ":\"method ID (=2)\",\"type\":\"integer\",\"maximum\":2},\"sloping_plane_classes"
    "_maximum_angle\":{\"minimum\":-360.0,\"description\":\"maximum inclination "
    "angle of sloping plane patches [deg]\",\"type\":\"number\",\"maximum\":360.0}"
    ",\"sloping_plane_classes_minimum_angle\":{\"minimum\":-360.0,\"description\""
    ":\"minimum inclination angle of sloping plane patches [deg]\",\"type\":\"nu"
    "mber\",\"maximum\":360.0}}},\"method-1\":{\"required\":[\"plane_classification"
    "_method\",\"maximum_inclination_angle_horizontal\"],\"description\":\"Classi"
    "fication method 1\",\"type\":\"object\",\"properties\":{\"plane_classification"
    "_method\":{\"minimum\":1,\"description\":\"method ID (=1)\",\"type\":\"integer\","
    "\"maximum\":1},\"maximum_inclination_angle_horizontal\":{\"minimum\":-360.0,"
    "\"description\":\"maximum inclination angle of horizontal plane patches "
    "[deg]\",\"type\":\"number\",\"maximum\":360.0}}}}}"
    ,
    /* example: */
    "{\"classes\":{\"14\":\"horizontal, pointing down\",\"6\":\"vertical, pointing "
    "east\",\"12\":\"sloping, pointing down and north\",\"2\":\"sloping, pointing "
    "up and east\",\"1\":\"horizontal, pointing up\",\"8\":\"vertical, pointing "
    "north\",\"7\":\"vertical, pointing south\",\"11\":\"sloping, pointing down and"
    " south\",\"9\":\"vertical, pointing west\",\"4\":\"sloping, pointing up and "
    "north\",\"3\":\"sloping, pointing up and south\",\"13\":\"sloping, pointing "
    "down and west\",\"5\":\"sloping, pointing up and west\",\"10\":\"sloping, "
    "pointing down and east\"},\"settings\":{\"plane_classification_method\":2,\""
    "sloping_plane_classes_maximum_angle\":70.0,\"sloping_plane_classes_minim"
    "um_angle\":10.0}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"additionalProperties\":false,\"description\":\"Grouping and sorting of "
    "point attributes for visualization purposes\",\"title\":\"Point Attribute "
    "Groups\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"ob"
    "ject\",\"patternProperties\":{\"^.*$\":{\"items\":{\"description\":\"Point "
    "attribute full name or name pattern (perl regular expression "
    "syntax)\",\"type\":\"string\"},\"description\":\"Each field of the object "
    "represents a point attribute group and holds a list of point "
    "attributes, where the field name is the group "
    "name.\",\"type\":\"array\",\"minItems\":1}}}"
    ,
    /* example: */
    "{\"Primary Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.de"
    "viation\"],\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.thet"
    "a\",\"riegl.phi\"],\"Time\":[\"riegl.timestamp\"],\"Other "
    "Attributes\":[\"riegl.selected\",\"riegl.visible\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"De"
    "tails about point cloud files\",\"title\":\"Point Cloud Information\",\"type"
    "\":\"object\",\"properties\":{\"field_of_application\":{\"description\":\"Field "
    "of application\",\"type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"M"
    "LS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"]},\"project\":{\"description\":\"Project name\","
    "\"type\":\"string\"},\"comments\":{\"description\":\"Comments\",\"type\":\"string\"}"
    "}}"
    ,
    /* example: */
    "{\"field_of_application\":\"ALS\",\"project\":\"Campaign 4\",\"comments\":\"Line "
    "3\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Estimated position and orientation information as "
    "measured by GNSS, IMU or inclination sensors\",\"title\":\"Pose Estimation"
    "\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ori"
    "entation\"],\"type\":\"object\",\"properties\":{\"barometric_height_amsl\":{\"de"
    "scription\":\"Altitude determined based on the atmospheric pressure "
    "according to the standard atmosphere laws [m].\",\"type\":\"number\"},\"posi"
    "tion\":{\"required\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_3\",\"horiz"
    "ontal_accuracy\",\"vertical_accuracy\",\"crs\"],\"description\":\"Position "
    "coordinates and position accuracy values as measured by GNSS in the "
    "specified Coordinate Reference System (CRS)\",\"type\":\"object\",\"properti"
    "es\":{\"crs\":{\"required\":[\"epsg\"],\"description\":\"Global Coordinate "
    "Reference System\",\"type\":\"object\",\"properties\":{\"epsg\":{\"minimum\":0,\"d"
    "escription\":\"EPSG "
    "code\",\"type\":\"integer\"},\"wkt\":{\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\",\"type\":\"string\"}}},\"coordinate_2\":{\"description\":\"Coordinate "
    "2 as defined by axis 2 of the specified CRS (e.g., Y, "
    "Longitude)\",\"type\":\"number\"},\"coordinate_1\":{\"description\":\"Coordinate"
    " 1 as defined by axis 1 of the specified CRS (e.g., X, Latitude)\",\"typ"
    "e\":\"number\"},\"vertical_accuracy\":{\"minimum\":0,\"exclusiveMinimum\":true,"
    "\"description\":\"Vertical accuracy "
    "[m]\",\"type\":\"number\"},\"coordinate_3\":{\"description\":\"Coordinate 3 as "
    "defined by axis 3 of the specified CRS (e.g., Z, Altitude)\",\"type\":\"nu"
    "mber\"},\"horizontal_accuracy\":{\"minimum\":0,\"exclusiveMinimum\":true,\"des"
    "cription\":\"Horizontal accuracy [m]\",\"type\":\"number\"}}},\"orientation\":{"
    "\"required\":[\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"yaw"
    "_accuracy\"],\"description\":\"Orientation values and orientation "
    "accuracies, measured with IMU or inclination sensors.\",\"type\":\"object\""
    ",\"properties\":{\"yaw\":{\"minimum\":-360,\"description\":\"Yaw angle about "
    "scanner Z-axis [deg]\",\"type\":\"number\",\"maximum\":360},\"pitch\":{\"minimum"
    "\":-360,\"description\":\"Pitch angle about scanner Y-axis [deg]\",\"type\":\""
    "number\",\"maximum\":360},\"yaw_accuracy\":{\"minimum\":0,\"exclusiveMinimum\":"
    "true,\"description\":\"Yaw angle accuracy [deg]\",\"type\":\"number\"},\"roll_a"
    "ccuracy\":{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"Roll "
    "angle accuracy "
    "[deg]\",\"type\":\"number\"},\"roll\":{\"minimum\":-360,\"description\":\"Roll "
    "angle about scanner X-axis [deg]\",\"type\":\"number\",\"maximum\":360},\"pitc"
    "h_accuracy\":{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"Pitch "
    "angle accuracy [deg]\",\"type\":\"number\"}}}}}"
    ,
    /* example: */
    "{\"barometric_height_amsl\":386.7457796227932,\"position\":{\"crs\":{\"epsg\":"
    "4979,\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"W"
    "GS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORI"
    "TY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHORI"
    "TY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.01745329251994329547,AUTHORIT"
    "Y[\\\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\\",EAST"
    "],AUTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\"},\"coordinate_2\":15.645033406,\"coordin"
    "ate_1\":48.655799473,\"vertical_accuracy\":1.3314999341964722,\"coordinate"
    "_3\":362.7124938964844,\"horizontal_accuracy\":0.810699999332428},\"orient"
    "ation\":{\"yaw\":101.87293630292045,\"pitch\":1.509153024827064,\"yaw_accura"
    "cy\":1.0094337839368757,\"roll_accuracy\":0.009433783936875745,\"roll\":3.1"
    "4743073066123,\"pitch_accuracy\":0.009433783936875745}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details on position and orientation "
    "sensors\",\"title\":\"Pose Sensors\",\"properties\":{\"magnetic_field_sensor\":"
    "{\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"relat"
    "ive_nonlinearity\"],\"description\":\"Magnetic Field Sensor details\",\"type"
    "\":\"object\",\"properties\":{\"relative_nonlinearity\":{\"description\":\"Relat"
    "ive nonlinearity, dimensionless\",\"$ref\":\"#/definitions/vector\"},\"offse"
    "t\":{\"description\":\"Value to be subtracted from raw measurement values\""
    ",\"$ref\":\"#/definitions/vector\"},\"fixed\":{\"description\":\"Distortion of "
    "magnetic field caused by non-rotating scanner part\",\"$ref\":\"#/definiti"
    "ons/vector\"},\"x_axis\":{\"description\":\"Sensitive X axis of sensor at "
    "frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"un"
    "it\":{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"Unit of raw "
    "data and calibration values, 1 LSB in "
    "nT\",\"type\":\"number\"},\"y_axis\":{\"description\":\"Sensitive Y axis of "
    "sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}}},\"accelerom"
    "eter\":{\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\""
    ",\"relative_nonlinearity\"],\"description\":\"Accelerometer "
    "details\",\"type\":\"object\",\"properties\":{\"origin\":{\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement values\",\"$ref\":\"#/definitions/vector\""
    "},\"relative_nonlinearity\":{\"description\":\"Relative nonlinearity, dimen"
    "sionless\",\"$ref\":\"#/definitions/vector\"},\"x_axis\":{\"description\":\"Sens"
    "itive X axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"un"
    "it\":{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"Unit of raw "
    "data and calibration values, 1 LSB in 9.81 "
    "m/s\\u00b2\",\"type\":\"number\"},\"y_axis\":{\"description\":\"Sensitive Y axis "
    "of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}}},\"gyrosc"
    "ope\":{\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\","
    "\"relative_nonlinearity\"],\"description\":\"Gyroscope "
    "details\",\"type\":\"object\",\"properties\":{\"origin\":{\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement values\",\"$ref\":\"#/definitions/vector\""
    "},\"relative_nonlinearity\":{\"description\":\"Relative nonlinearity, dimen"
    "sionless\",\"$ref\":\"#/definitions/vector\"},\"x_axis\":{\"description\":\"Sens"
    "itive X axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"un"
    "it\":{\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"Unit of raw "
    "data and calibration values, 1 LSB in "
    "rad/s\",\"type\":\"number\"},\"y_axis\":{\"description\":\"Sensitive Y axis of "
    "sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"}}}},\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"gyroscope\",\"ac"
    "celerometer\",\"magnetic_field_sensor\"],\"type\":\"object\",\"definitions\":{\""
    "vector\":{\"maxItems\":3,\"items\":{\"description\":\"Index 0=X, 1=Y, 2=Z "
    "component\",\"type\":\"number\"},\"type\":\"array\",\"minItems\":3}}}"
    ,
    /* example: */
    "{\"magnetic_field_sensor\":{\"relative_nonlinearity\":[0.0,0.0,0.0],\"offse"
    "t\":[-23812.052734375,5606.57666015625,2493.28125],\"fixed\":[-1576.01049"
    "8046875,1596.081787109375,0.0],\"x_axis\":[-0.011162743903696537,-2.3159"
    "62774446234e-05,0.00016818844596855342],\"z_axis\":[0.000419878662796691"
    "06,7.876977906562388e-05,0.011407104320824146],\"unit\":91.7431182861328"
    "1,\"y_axis\":[0.00027888521435670555,-0.011427424848079681,-5.2048297220"
    "60822e-05]},\"accelerometer\":{\"origin\":[0.026900000870227814,-0.0399999"
    "9910593033,-0.08950000256299973],\"offset\":[-733.3636474609375,58.96903"
    "2287597656,1060.2550048828125],\"relative_nonlinearity\":[0.0,0.0,0.0],\""
    "x_axis\":[-15008.123046875,56.956390380859375,-60.5175666809082],\"z_axi"
    "s\":[1.639882206916809,15166.744140625,-116.99742889404297],\"unit\":6.66"
    "6666740784422e-05,\"y_axis\":[-7.027288913726807,-44.12333679199219,1495"
    "2.3701171875]},\"gyroscope\":{\"origin\":[0.026900000870227814,-0.03999999"
    "910593033,-0.08950000256299973],\"offset\":[-50.92609786987305,146.15643"
    "310546875,62.4327278137207],\"relative_nonlinearity\":[2.888176311444113"
    "e-07,1.06274164579645e-07,-1.7186295080634935e-39],\"x_axis\":[-121.1955"
    "56640625,0.8219714164733887,0.2313031703233719],\"z_axis\":[0.5558699965"
    "47699,119.22135162353516,0.467585027217865],\"unit\":0.00014544410805683"
    "583,\"y_axis\":[-0.440765917301178,-0.7897399663925171,119.5894775390625"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Laser pulse position modulation used for MTA "
    "resolution\",\"title\":\"Pulse Position Modulation\",\"$schema\":\"http://json"
    "-schema.org/draft-04/schema#\",\"required\":[\"length\",\"num_mod_ampl\",\"pul"
    "se_interval\"],\"type\":\"object\",\"properties\":{\"pulse_interval\":{\"items\":"
    "{\"minimum\":0,\"type\":\"number\"},\"description\":\"Explicit table of the "
    "pulse position modulation used for MTA resolution. Table gives times "
    "between successive laser pulses in "
    "seconds.\",\"type\":\"array\"},\"length\":{\"minimum\":0,\"description\":\"Length "
    "of code\",\"type\":\"integer\",\"maximum\":255},\"num_mod_ampl\":{\"minimum\":0,\""
    "description\":\"Number of different modulation amplitudes (2: binary mod"
    "ulation)\",\"type\":\"integer\",\"maximum\":255},\"code_phase_mode\":{\"minimum\""
    ":0,\"description\":\"0: no synchronization, 1: toggle between 2 phases, "
    "2: increment with phase_increment\",\"type\":\"integer\",\"maximum\":255},\"ph"
    "ase_step\":{\"minimum\":0,\"description\":\"Step width in phase of "
    "modulation code from line to line\",\"type\":\"integer\",\"maximum\":255}}}"
    ,
    /* example: */
    "{\"pulse_interval\":[2.759375e-06,2.759375e-06,2.759375e-06,2.759375e-06"
    ",2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.82"
    "1875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e"
    "-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2"
    ".759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.8218"
    "75e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-0"
    "6],\"length\":31,\"num_mod_ampl\":2,\"code_phase_mode\":2,\"phase_step\":5}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Statistics about target distance wrt. SOCS "
    "origin\",\"title\":\"Range Statistics\",\"$schema\":\"http://json-schema.org/d"
    "raft-04/schema#\",\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],"
    "\"type\":\"object\",\"properties\":{\"minimum\":{\"description\":\"Minimum "
    "value\",\"type\":\"number\"},\"average\":{\"description\":\"Average "
    "value\",\"type\":\"number\"},\"std_dev\":{\"description\":\"Standard "
    "deviation\",\"type\":\"number\"},\"maximum\":{\"description\":\"Maximum "
    "value\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"minimum\":0.919,\"average\":15.49738,\"std_dev\":24.349,\"maximum\":574.35}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Receiver Internals\",\"title\":\"Receiver "
    "Internals\",\"properties\":{\"a\":{\"maxItems\":256,\"description\":\"Amplitude "
    "[dB]\",\"items\":{\"type\":\"number\"},\"type\":\"array\",\"minItems\":1},\"tbl\":{\"d"
    "escription\":\"various internal data\",\"items\":{\"$ref\":\"#/definitions/fp_"
    "table\"},\"type\":\"array\",\"minItems\":1},\"sr\":{\"description\":\"Sample rate "
    "[Hz]\",\"exclusiveMinimum\":true,\"minimum\":0,\"type\":\"number\"},\"mw\":{\"desc"
    "ription\":\"Maximum weight\",\"exclusiveMinimum\":true,\"minimum\":0,\"type\":\""
    "number\",\"maximum\":4095},\"ns\":{\"description\":\"Number of samples\",\"minim"
    "um\":0,\"type\":\"integer\",\"maximum\":4095},\"ex\":{\"description\":\"DEPRECATED"
    ", use 'riegl.exponential_decomposition' "
    "instead\",\"type\":\"object\"},\"si\":{\"description\":\"Start index (hw_start)\""
    ",\"minimum\":0,\"type\":\"number\",\"maximum\":255},\"t\":{\"patternProperties\":{"
    "\"^[0-9]+$\":{\"description\":\"one field per channel, field name is "
    "channel index\",\"$ref\":\"#/definitions/fp\"}},\"type\":\"object\",\"additional"
    "Properties\":false},\"nt\":{\"description\":\"Number of traces\",\"minimum\":0,"
    "\"type\":\"integer\",\"maximum\":255}},\"$schema\":\"http://json-schema.org/dra"
    "ft-04/schema#\",\"type\":\"object\",\"definitions\":{\"fp\":{\"required\":[\"s\",\"w"
    "\"],\"description\":\"Fingerprint values\",\"type\":\"object\",\"properties\":{\"s"
    "\":{\"maxItems\":256,\"items\":{\"maxItems\":4096,\"items\":{\"type\":\"number\"},\""
    "type\":\"array\",\"minItems\":1},\"type\":\"array\",\"minItems\":1},\"w\":{\"maxItem"
    "s\":256,\"items\":{\"maxItems\":5,\"items\":{\"type\":\"number\"},\"type\":\"array\","
    "\"minItems\":5},\"type\":\"array\",\"minItems\":1}}},\"fp_table_row\":{\"maxItems"
    "\":2048,\"items\":{\"type\":\"number\"},\"type\":\"array\",\"minItems\":1},\"fp_tabl"
    "e\":{\"required\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"],\"properties\":{\"ny\":{\"max\":20"
    "48,\"description\":\"number of y entries\",\"type\":\"integer\",\"min\":1},\"ch\":"
    "{\"max\":255,\"description\":\"channel "
    "number\",\"type\":\"integer\",\"min\":0},\"tc\":{\"max\":255,\"description\":\"table"
    " data type "
    "code\",\"type\":\"integer\",\"min\":0},\"nx\":{\"max\":2048,\"description\":\"number"
    " of x entries\",\"type\":\"integer\",\"min\":1},\"tv\":{\"maxItems\":2048,\"items\""
    ":{\"oneOf\":[{\"$ref\":\"#/definitions/fp_table_row\"},{\"type\":\"number\"}]},\""
    "type\":\"array\",\"minItems\":1}},\"type\":\"object\",\"desription\":\"scanner "
    "internal data\"}}}"
    ,
    /* example: */
    "{\"a\":[-1.55],\"tbl\":[{\"ny\":2,\"ch\":0,\"tc\":1,\"nx\":5,\"tv\":[[1,2,3,4,5],[1."
    "1,2.2,3.3,4.4,5.5]]}],\"sr\":7959997000.0,\"mw\":31,\"ns\":400,\"si\":48,\"t\":{"
    "\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],[78,86,126,"
    "134,31]]},\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],["
    "78,86,126,134,31]]}},\"nt\":128}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Lookup table for reflectance calculation based on "
    "amplitude and range\",\"title\":\"Reflectance Calculation Table\",\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"delta\",\"conten"
    "t\"],\"type\":\"object\",\"properties\":{\"delta\":{\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\",\"type\":\"numb"
    "er\"},\"content\":{\"items\":{\"type\":\"number\"},\"maxItems\":2000,\"description"
    "\":\"Correction value [dB] to be added to the "
    "amplitude\",\"type\":\"array\",\"minItems\":1}}}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Range-dependent and scan-angle-dependent correction of"
    " reflectance reading\",\"title\":\"Near-range reflectance correction\",\"$sc"
    "hema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ranges_m\""
    ",\"line_angles_deg\",\"reflectance_correction_db\"],\"type\":\"object\",\"prope"
    "rties\":{\"reflectance_correction_db\":{\"items\":{\"items\":{\"description\":\""
    "columns (each value corresponds to an "
    "angle)\",\"type\":\"number\"},\"description\":\"rows (each array corresponds "
    "to a range)\",\"type\":\"array\"},\"description\":\"Near range reflectance "
    "correction in dB as a function of range over angle\",\"type\":\"array\"},\"r"
    "anges_m\":{\"items\":{\"type\":\"number\"},\"description\":\"Range [m]\",\"type\":\""
    "array\"},\"line_angles_deg\":{\"items\":{\"type\":\"number\"},\"description\":\"An"
    "gle [deg]\",\"type\":\"array\"}}}"
    ,
    /* example: */
    "{\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0."
    "01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0"
    ".3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"ra"
    "nges_m\":[0.0,1.0,2.0,3.0],\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2"
    ".5,3.0,3.5,4.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Sc"
    "an pattern description\",\"title\":\"Scan Pattern\",\"properties\":{\"rectangu"
    "lar\":{\"required\":[\"phi_start\",\"phi_stop\",\"phi_increment\",\"theta_start\""
    ",\"theta_stop\",\"theta_increment\"],\"description\":\"Rectangular Field Of "
    "View Scan Pattern\",\"type\":\"object\",\"properties\":{\"theta_stop\":{\"minimu"
    "m\":0.0,\"description\":\"Stop theta angle in SOCS [deg]\",\"type\":\"number\","
    "\"maximum\":180.0},\"program\":{\"$ref\":\"#/definitions/program\"},\"theta_inc"
    "rement\":{\"minimum\":0.0,\"description\":\"Increment of theta angle in SOCS"
    " [deg]\",\"type\":\"number\",\"maximum\":90.0},\"phi_start\":{\"minimum\":0.0,\"de"
    "scription\":\"Start phi angle in SOCS [deg]\",\"type\":\"number\",\"maximum\":3"
    "60.0},\"theta_start\":{\"minimum\":0.0,\"description\":\"Start theta angle in"
    " SOCS [deg]\",\"type\":\"number\",\"maximum\":180.0},\"phi_increment\":{\"minimu"
    "m\":0.0,\"description\":\"Increment of phi angle in SOCS [deg]\",\"type\":\"nu"
    "mber\",\"maximum\":90.0},\"phi_stop\":{\"minimum\":0.0,\"description\":\"Stop "
    "phi angle in SOCS [deg]\",\"type\":\"number\",\"maximum\":720.0}}},\"segments\""
    ":{\"required\":[\"list\"],\"description\":\"Segmented Line Scan Pattern\",\"typ"
    "e\":\"object\",\"properties\":{\"list\":{\"items\":{\"required\":[\"start\",\"stop\","
    "\"increment\"],\"description\":\"Line Scan Segment\",\"type\":\"object\",\"proper"
    "ties\":{\"increment\":{\"minimum\":0.0,\"description\":\"Increment of angle in"
    " SOCS [deg]\",\"type\":\"number\",\"maximum\":90.0},\"start\":{\"minimum\":0.0,\"d"
    "escription\":\"Start angle in SOCS [deg]\",\"type\":\"number\",\"maximum\":360."
    "0},\"stop\":{\"minimum\":0.0,\"description\":\"Stop angle in SOCS [deg]\",\"typ"
    "e\":\"number\",\"maximum\":720.0}}},\"type\":\"array\"},\"program\":{\"$ref\":\"#/de"
    "finitions/program\"}}},\"line\":{\"required\":[\"start\",\"stop\",\"increment\"],"
    "\"description\":\"Line Scan Pattern\",\"type\":\"object\",\"properties\":{\"incre"
    "ment\":{\"minimum\":0.0,\"description\":\"Increment of angle in SOCS [deg]\","
    "\"type\":\"number\",\"maximum\":90.0},\"program\":{\"$ref\":\"#/definitions/progr"
    "am\"},\"start\":{\"minimum\":0.0,\"description\":\"Start angle in SOCS [deg]\","
    "\"type\":\"number\",\"maximum\":360.0},\"stop\":{\"minimum\":0.0,\"description\":\""
    "Stop angle in SOCS [deg]\",\"type\":\"number\",\"maximum\":720.0}}}},\"definit"
    "ions\":{\"program\":{\"required\":[\"name\"],\"description\":\"Measurement "
    "program\",\"type\":\"object\",\"properties\":{\"name\":{\"description\":\"Name of "
    "measurement program\",\"type\":\"string\"},\"laser_prr\":{\"minimum\":0,\"exclus"
    "iveMinimum\":false,\"description\":\"Laser Pulse Repetition Rate "
    "[Hz]\",\"type\":\"number\"}}}}}"
    ,
    /* example: */
    "{\"rectangular\":{\"theta_stop\":130.0,\"program\":{\"name\":\"High Speed\",\"las"
    "er_prr\":100000.0},\"theta_increment\":0.04,\"phi_start\":45.0,\"theta_start"
    "\":30.0,\"phi_increment\":0.04,\"phi_stop\":270.0}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"De"
    "tails about laser shot files\",\"title\":\"Shot Information\",\"type\":\"objec"
    "t\",\"properties\":{\"shot_file\":{\"required\":[\"file_extension\"],\"type\":\"ob"
    "ject\",\"properties\":{\"file_uuid\":{\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Shot file "
    "extension, without the leading dot\",\"type\":\"string\"}}}}}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Point filters applied in addition to the "
    "application-defined filters\",\"title\":\"Stored filters\",\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"required\":[\"activated\",\"filters\"]"
    ",\"type\":\"object\",\"properties\":{\"filters\":{\"items\":{\"required\":[\"activa"
    "ted\",\"title\",\"description\",\"filter\"],\"description\":\"Point filter "
    "definition\",\"type\":\"object\",\"properties\":{\"filter\":{\"description\":\"The"
    " RDB filter string to apply (e.g. when reading points or index), "
    "details see documentation of function "
    "select()\",\"type\":\"string\"},\"description\":{\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\",\"type\":\"string\"},\"title\":{\"description\":\"A short filter "
    "title (e.g. for display in a selection "
    "list)\",\"type\":\"string\"},\"activated\":{\"description\":\"Apply ('true') or "
    "ignore ('false') this filter\",\"type\":\"boolean\"}}},\"description\":\"List "
    "of point filters\",\"type\":\"array\"},\"activated\":{\"description\":\"Apply "
    "('true') or ignore ('false') all filters\",\"type\":\"boolean\"}}}"
    ,
    /* example: */
    "{\"filters\":[{\"filter\":\"riegl.mta_uncertain_point == "
    "0\",\"description\":\"Ignore points with uncertain MTA zone "
    "assignment\",\"title\":\"Ignore uncertain points from MTA resolution\",\"act"
    "ivated\":false},{\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"description\":\"Ignore points with an echo signal amplitude below "
    "the dynamic trigger\",\"title\":\"Ignore points below dynamic trigger "
    "level\",\"activated\":false},{\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are outside the outer AABB in "
    "BOCS\",\"title\":\"Ignore points outside outer "
    "AABB\",\"activated\":false},{\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"description\":\"Ignore points that are inside the inner AABB in "
    "BOCS\",\"title\":\"Ignore points inside inner "
    "AABB\",\"activated\":false}],\"activated\":true}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details of major system components like lidar sensors,"
    " cameras and navigation devices\",\"title\":\"System Description\",\"$schema"
    "\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"$class\",\"vers"
    "ion\",\"author\",\"timestamp\",\"system\"],\"type\":\"object\",\"properties\":{\"sys"
    "tem\":{\"description\":\"The actual system description, details see "
    "documentation of RIEGL System "
    "Description\",\"type\":\"object\"},\"$class\":{\"description\":\"Object class na"
    "me\",\"type\":\"string\",\"enum\":[\"Document\"]},\"timestamp\":{\"description\":\"D"
    "ate and time of creation (e.g. 2019-06-19T13:32:10+02:00)\",\"type\":\"str"
    "ing\"},\"version\":{\"description\":\"Document format "
    "version\",\"type\":\"string\"},\"author\":{\"description\":\"Name of the author "
    "that created the document\",\"type\":\"string\"}}}"
    ,
    /* example: */
    "{\"system\":{\"details\":\"see documentation of RIEGL System Description\"},"
    "\"$class\":\"Document\",\"timestamp\":\"2022-09-30T11:56:26+00:00\",\"version\":"
    "\"1.2.1\",\"author\":\"RIEGL LMS GmbH, Austria\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Conversion of background radiation raw values to "
    "temperatures in \\u00b0C\",\"title\":\"Temperature Calculation "
    "Table\",\"properties\":{\"InGaAs\":{\"description\":\"Conversion table for "
    "InGaAs channel\",\"$ref\":\"#/definitions/conversion_table\"},\"InGaAs_Si_Di"
    "fference\":{\"description\":\"Conversion table for InGaAs - Si difference\""
    ",\"$ref\":\"#/definitions/conversion_table\"},\"Si\":{\"description\":\"Convers"
    "ion table for Si channel\",\"$ref\":\"#/definitions/conversion_table\"}},\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"def"
    "initions\":{\"conversion_table\":{\"required\":[\"value\",\"temperature\"],\"typ"
    "e\":\"object\",\"properties\":{\"value\":{\"items\":{\"type\":\"number\"},\"descript"
    "ion\":\"LSB [1]\",\"type\":\"array\"},\"temperature\":{\"items\":{\"type\":\"number\""
    "},\"description\":\"Temperature [\\u00b0C]\",\"type\":\"array\"}}}}}"
    ,
    /* example: */
    "{\"InGaAs\":{\"value\":[0.0,64.00097659230323,128.0019531846065,192.002929"
    "7769097,256.0039063692129,320.00488296151616,384.0058595538194,448.006"
    "8361461226,512.0078127384259],\"temperature\":[307.22196722535614,309.11"
    "53478247277,311.1188086915047,313.10025350480055,315.2137946389828,317"
    ".2172555057597,319.2207163725366,321.2021611858325,323.3157023200148]}"
    ",\"InGaAs_Si_Difference\":{\"value\":[1000.0,1100.090029602954,1200.044251"
    "83874,1300.1342814416948,1400.0885036774805,1500.0427259132668,1600.13"
    "27555162209,1700.0869777520065,1800.0411999877924],\"temperature\":[1749"
    ".977111117893,1749.977111117893,1749.977111117893,1749.977111117893,17"
    "49.977111117893,1749.977111117893,1744.7813348796044,1681.997131260109"
    "2,1622.3944822534868]},\"Si\":{\"value\":[0.0,64.00097659230323,128.001953"
    "1846065,192.0029297769097,256.0039063692129,320.00488296151616,384.005"
    "8595538194,448.0068361461226,512.0078127384259],\"temperature\":[546.300"
    "048828125,548.8164051212026,551.3143938500972,554.0144257850053,556.60"
    "4252334815,559.2124464488079,561.8022729986177,564.4104671126105,567.0"
    "002936624203]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Base of timestamps (epoch)\",\"title\":\"Time Base\",\"$sche"
    "ma\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"epoch\",\"sou"
    "rce\"],\"type\":\"object\",\"properties\":{\"system\":{\"description\":\"Time "
    "system (time standard)\",\"type\":\"string\",\"enum\":[\"unknown\",\"UTC\",\"GPS\"]"
    "},\"source\":{\"description\":\"Timestamp source\",\"type\":\"string\",\"enum\":[\""
    "unknown\",\"RTC\",\"GNSS\"]},\"epoch\":{\"description\":\"Date and time of "
    "timestamp '0' as proposed by RFC 3339 (e.g. "
    "2015-10-27T00:00:00+01:00).\",\"type\":\"string\"}}}"
    ,
    /* example: */
    "{\"system\":\"UTC\",\"source\":\"GNSS\",\"epoch\":\"2015-10-27T00:00:00+00:00\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about position+orientation "
    "files\",\"title\":\"Trajectory Information\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"required\":[\"time_interval\",\"navigation_frame\"],"
    "\"type\":\"object\",\"properties\":{\"location\":{\"description\":\"Project "
    "location, e.g. city/state/country\",\"type\":\"string\"},\"field_of_applicat"
    "ion\":{\"description\":\"Field of application\",\"type\":\"string\",\"enum\":[\"un"
    "known\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"]},\"project\":{\"d"
    "escription\":\"Project "
    "name\",\"type\":\"string\"},\"settings\":{\"description\":\"Settings used to "
    "calculate the trajectory (descriptive "
    "text)\",\"type\":\"string\"},\"software\":{\"description\":\"Software that "
    "calculated the trajectory (this may be the same or different software "
    "than the one that created the "
    "file)\",\"type\":\"string\"},\"device\":{\"description\":\"Navigation device, "
    "e.g. name/type/serial\",\"type\":\"string\"},\"navigation_frame\":{\"descripti"
    "on\":\"Navigation frame (NED: North-East-Down, ENU: East-North-Up)\",\"typ"
    "e\":\"string\",\"enum\":[\"unknown\",\"NED\",\"ENU\"]},\"time_interval\":{\"required"
    "\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"description\":\"Time "
    "interval statistics\",\"type\":\"object\",\"properties\":{\"minimum\":{\"descrip"
    "tion\":\"Minimum time interval "
    "[s]\",\"type\":\"number\"},\"average\":{\"description\":\"Average time interval "
    "[s]\",\"type\":\"number\"},\"std_dev\":{\"description\":\"Standard deviation of "
    "intervals [s]\",\"type\":\"number\"},\"maximum\":{\"description\":\"Maximum time"
    " interval [s]\",\"type\":\"number\"}}},\"company\":{\"description\":\"Company "
    "name\",\"type\":\"string\"}}}"
    ,
    /* example: */
    "{\"location\":\"Horn\",\"field_of_application\":\"MLS\",\"project\":\"Campaign "
    "3\",\"settings\":\"default\",\"software\":\"Navigation Software "
    "XYZ\",\"device\":\"IMU Model 12/1, Serial# 12345\",\"navigation_frame\":\"NED\""
    ",\"time_interval\":{\"minimum\":0.00500032,\"average\":0.00500053,\"std_dev\":"
    "5.51e-07,\"maximum\":0.005004883},\"company\":\"RIEGL LMS\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Trigger-Timestamping-Unit/IP "
    "configuration\",\"title\":\"TTIP Configuration\",\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"required\":[\"ttip_version\",\"num_channel\",\"ex"
    "t_channel\",\"ext_signal\",\"ext_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dm"
    "i_incr\",\"dmi_min_time\",\"dmi_max_time\",\"dmi_dist_per_tick\",\"channel\",\"o"
    "utput_descr\",\"input_descr\",\"output_usage\",\"input_usage\",\"out_polarity\""
    ",\"out_duration\",\"out_interval\",\"out_delay\",\"out_num_pulses\",\"in_polari"
    "ty\",\"in_min_duration\",\"in_max_duration\",\"in_max_delay\"],\"type\":\"object"
    "\",\"properties\":{\"ext_bitmask\":{\"minimum\":0,\"description\":\"defines "
    "which of the internal pulse generators are to be started\",\"type\":\"inte"
    "ger\"},\"ext_channel\":{\"minimum\":0,\"description\":\"ID of channel used as "
    "external trigger input, 32 indicates "
    "none\",\"type\":\"integer\"},\"output_usage\":{\"minimum\":0,\"description\":\"0 "
    ".. no output, 1 .. output derived from internal clock, 2 .. output "
    "derived from dmi, 3 .. output derived from external signal, 4 .. "
    "output static low, 5 .. output static high\",\"type\":\"integer\"},\"dmi_min"
    "_time\":{\"minimum\":0,\"description\":\"dmi, minimum time interval between "
    "trigger events [0.1 msec]\",\"type\":\"integer\"},\"out_duration\":{\"minimum\""
    ":0,\"description\":\"output pulse duration [0.1 "
    "msec]\",\"type\":\"integer\"},\"channel\":{\"minimum\":0,\"description\":\"ID of "
    "input/output channel\",\"type\":\"integer\"},\"in_max_duration\":{\"minimum\":0"
    ",\"description\":\"stops measurement of pulse duration of input signal "
    "[0.1 msec]\",\"type\":\"integer\"},\"dmi_max_time\":{\"minimum\":0,\"description"
    "\":\"dmi, maximum time interval between trigger events [0.1 "
    "msec]\",\"type\":\"integer\"},\"ext_signal\":{\"minimum\":0,\"description\":\"0 .."
    " use input signal, 1 .. use output signal of channel\",\"type\":\"integer\""
    "},\"ext_subdivider\":{\"minimum\":0,\"description\":\"reduces the frequency, "
    "default 1\",\"type\":\"integer\"},\"in_min_duration\":{\"minimum\":0,\"descripti"
    "on\":\"input signals with smaller pulse durations are ignored [0.1 "
    "msec]\",\"type\":\"integer\"},\"dmi_incr\":{\"description\":\"dmi, increment in "
    "ticks\",\"type\":\"integer\"},\"in_polarity\":{\"minimum\":0,\"description\":\"0 "
    ".. positive edge, 1 .. negative edge\",\"type\":\"integer\"},\"in_max_delay\""
    ":{\"minimum\":0,\"description\":\"maximum delay to output pulse before fake"
    " event is generated [0.1 msec], zero indicates that no fake events are"
    " generated\",\"type\":\"integer\"},\"ttip_version\":{\"minimum\":0,\"description"
    "\":\"following main.sub.ss.sss\",\"type\":\"integer\"},\"out_interval\":{\"minim"
    "um\":0,\"description\":\"output pulse interval [0.1 msec]\",\"type\":\"integer"
    "\"},\"ext_delay\":{\"minimum\":0,\"description\":\"external trigger, time "
    "delay [0.1 "
    "msec]\",\"type\":\"integer\"},\"out_polarity\":{\"minimum\":0,\"description\":\"0 "
    ".. positive edge, 1 .. negative "
    "edge\",\"type\":\"integer\"},\"input_usage\":{\"minimum\":0,\"description\":\"0 .."
    " deactivated, 1 .. just detecting and timestamping\",\"type\":\"integer\"},"
    "\"out_num_pulses\":{\"minimum\":0,\"description\":\"number of output pulses "
    "to be generated, 0 .. "
    "infinite\",\"type\":\"integer\"},\"output_descr\":{\"description\":\"descriptive"
    " string\",\"type\":\"string\"},\"dmi_dist_per_tick\":{\"description\":\"dmi, "
    "distance per tick, just informative "
    "[m]\",\"type\":\"number\"},\"out_delay\":{\"minimum\":0,\"description\":\"output "
    "pulse initial delay after start [0.1 msec]\",\"type\":\"integer\"},\"num_cha"
    "nnel\":{\"minimum\":0,\"description\":\"number of input/output "
    "channels\",\"type\":\"integer\"},\"input_descr\":{\"description\":\"descriptive "
    "string\",\"type\":\"string\"}}}"
    ,
    /* example: */
    "{\"ext_bitmask\":0,\"ext_channel\":32,\"output_usage\":1,\"dmi_min_time\":0,\"o"
    "ut_duration\":300,\"channel\":0,\"in_max_duration\":10000,\"dmi_max_time\":0,"
    "\"ext_signal\":0,\"ext_subdivider\":1,\"in_min_duration\":0,\"dmi_incr\":0,\"in"
    "_polarity\":0,\"in_max_delay\":9990,\"ttip_version\":1,\"out_interval\":10000"
    ",\"ext_delay\":0,\"out_polarity\":0,\"input_usage\":1,\"out_num_pulses\":1,\"ou"
    "tput_descr\":\"Port 1 - Trigger\",\"dmi_dist_per_tick\":0.0,\"out_delay\":0,\""
    "num_channel\":9,\"input_descr\":\"Port 1 - Exposure\"}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"De"
    "tails about vertex file\",\"title\":\"Vertex Information\",\"type\":\"object\","
    "\"properties\":{\"vertex_file\":{\"required\":[\"file_extension\"],\"type\":\"obj"
    "ect\",\"properties\":{\"file_uuid\":{\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Vertex file "
    "extension, without the leading dot\",\"type\":\"string\"}}}}}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"oneOf\":[{\"required\":[\"size\",\"voxel_origin\",\"voxel_type\"],\"additional"
    "Properties\":false,\"properties\":{\"shape_thresholds\":{\"$ref\":\"#/definiti"
    "ons/shape_thresholds\"},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\""
    "},\"voxel_origin\":{\"$ref\":\"#/definitions/voxel_origin_enum\"},\"size\":{\"o"
    "neOf\":[{\"$ref\":\"#/definitions/voxel_size\"},{\"$ref\":\"#/definitions/voxe"
    "l_size_cubic\"}],\"description\":\"Size of voxels in file coordinate syste"
    "m.\"}}},{\"required\":[\"reference_point\",\"size_llcs\",\"size\",\"voxel_origin"
    "\",\"voxel_type\"],\"additionalProperties\":false,\"properties\":{\"size_llcs\""
    ":{\"description\":\"Size of voxels in a locally levelled cartesian "
    "coordinate system (xyz). This is only used for voxels based on a map p"
    "rojection.\",\"$ref\":\"#/definitions/voxel_size\"},\"reference_point\":{\"max"
    "Items\":2,\"items\":{\"minimum\":-180,\"type\":\"number\",\"maximum\":180},\"minIt"
    "ems\":2,\"description\":\"Point in WGS84 geodetic decimal degree "
    "(EPSG:4326) that was used to compute the projection distortion "
    "parameters. The coefficient order is latitude, longitude. Only voxels "
    "with corresponding geo_tag, voxel_size and reference_point can be "
    "reliably processed together. This entry is available for voxel files "
    "in projected CRS only.\",\"type\":\"array\"},\"voxel_origin\":{\"oneOf\":[{\"$re"
    "f\":\"#/definitions/voxel_origin_enum\"},{\"description\":\"The base point "
    "of the voxel grid. Used together with <tt>voxel_size</tt> and "
    "<tt>voxel_index</tt> to compute actual point coordinates.\",\"$ref\":\"#/d"
    "efinitions/voxel_origin_point\"}]},\"size\":{\"description\":\"Size of "
    "voxels in file coordinate system.\",\"$ref\":\"#/definitions/voxel_size\"},"
    "\"shape_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"voxel_ty"
    "pe\":{\"$ref\":\"#/definitions/voxel_type\"}}}],\"description\":\"Details "
    "about the voxels contained in the file\",\"title\":\"Voxel Information\",\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"type\":\"object\",\"def"
    "initions\":{\"voxel_origin_point\":{\"items\":{\"type\":\"number\"},\"maxItems\":"
    "3,\"description\":\"Origin point for all voxel indices in voxel CRS.\",\"ty"
    "pe\":\"array\",\"minItems\":3},\"edge_length\":{\"minimum\":0,\"exclusiveMinimum"
    "\":true,\"description\":\"Length of voxel edge [m].\",\"type\":\"number\"},\"vox"
    "el_size\":{\"maxItems\":3,\"items\":{\"$ref\":\"#/definitions/edge_length\"},\"m"
    "inItems\":3,\"description\":\"Size of voxels.\",\"type\":\"array\"},\"shape_thre"
    "sholds\":{\"required\":[\"plane\",\"line\"],\"description\":\"Thresholds used to"
    " compute the voxel's shape_id "
    "value.\",\"type\":\"object\",\"properties\":{\"plane\":{\"description\":\"If the "
    "smallest eigenvalue is smaller than the median eigenvalue * "
    "plane_threshold, the voxel is considered a plane.\",\"maximum\":1,\"exclus"
    "iveMinimum\":true,\"minimum\":0,\"type\":\"number\",\"exclusiveMaximum\":true},"
    "\"line\":{\"minimum\":1,\"exclusiveMinimum\":true,\"description\":\"If the "
    "biggest eigenvalue is bigger than the median eigenvalue * "
    "line_threshold, the voxel is considered a line.\",\"type\":\"number\"}}},\"v"
    "oxel_type\":{\"default\":\"centroid\",\"description\":\"Whether a point in a "
    "voxel represents its center or its centroid. If type is <tt>index</tt>"
    " there is no point but only an integer voxel index.\",\"enum\":[\"center\","
    "\"centroid\",\"index\"]},\"voxel_size_cubic\":{\"type\":\"number\",\"$ref\":\"#/def"
    "initions/edge_length\"},\"voxel_origin_enum\":{\"default\":\"corner\",\"descri"
    "ption\":\"Defines whether the voxel's center or a corner is placed on "
    "CRS origin <tt>(0/0/0)</tt>.\",\"enum\":[\"center\",\"corner\"]}}}"
    ,
    /* example: */
    "{\"shape_thresholds\":{\"plane\":0.16,\"line\":6},\"reference_point\":[48,16],"
    "\"voxel_origin\":\"corner\",\"size\":[0.5971642834779395,0.5971642834779395,"
    "0.5143705304787237],\"size_llcs\":[0.5156575252891171,0.5130835356683303"
    ",0.5143705304787237],\"voxel_type\":\"centroid\"}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Settings for waveform averaging\",\"title\":\"Waveform "
    "Averaging Settings\",\"$schema\":\"http://json-schema.org/draft-04/schema#"
    "\",\"required\":[\"num_shots\",\"mta_zone\"],\"type\":\"object\",\"properties\":{\"m"
    "ta_zone\":{\"minimum\":1,\"description\":\"Fixed MTA zone for averaging.\",\"t"
    "ype\":\"integer\"},\"num_shots\":{\"minimum\":1,\"description\":\"Number of "
    "consecutive shots to be used for averaging.\",\"type\":\"integer\"},\"trim\":"
    "{\"default\":0,\"minimum\":0,\"description\":\"Percentage for robust "
    "averaging.\",\"type\":\"number\",\"maximum\":0.5}}}"
    ,
    /* example: */
    "{\"mta_zone\":1,\"num_shots\":7,\"trim\":0.05}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Details about waveform files\",\"title\":\"Waveform Inform"
    "ation\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":"
    "[\"sample_block_file\",\"sample_data_files\"],\"type\":\"object\",\"properties\""
    ":{\"range_offset_waveform_samples_m\":{\"description\":\"Calibrated device "
    "specific range offset for waveform samples in meters.\",\"type\":\"number\""
    "},\"sample_data_files\":{\"items\":{\"required\":[\"channel\",\"channel_name\",\""
    "sample_interval\",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"file_ext"
    "ension\"],\"type\":\"object\",\"properties\":{\"delta_st\":{\"description\":\"rese"
    "rved\",\"type\":\"number\"},\"sample_interval\":{\"minimum\":0,\"exclusiveMinimu"
    "m\":false,\"description\":\"Sampling interval in "
    "seconds\",\"type\":\"number\"},\"channel_name\":{\"description\":\"Sample block "
    "channel name\",\"type\":\"string\"},\"file_uuid\":{\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Sample data "
    "file extension, without the leading "
    "dot\",\"type\":\"string\"},\"channel\":{\"description\":\"Sample block channel "
    "number (255 = invalid)\",\"maximum\":255,\"exclusiveMinimum\":false,\"minimu"
    "m\":0,\"type\":\"integer\",\"exclusiveMaximum\":false},\"laser_wavelength\":{\"m"
    "inimum\":0,\"exclusiveMinimum\":false,\"description\":\"Laser wavelength in "
    "meters (0 = "
    "unknown)\",\"type\":\"number\"},\"sample_bits\":{\"description\":\"Bitwidth of "
    "samples (e.g. 10 bit, 12 bit)\",\"maximum\":32,\"exclusiveMinimum\":false,\""
    "minimum\":0,\"type\":\"integer\",\"exclusiveMaximum\":false}}},\"type\":\"array\""
    "},\"sample_block_file\":{\"required\":[\"file_extension\"],\"type\":\"object\",\""
    "properties\":{\"file_uuid\":{\"description\":\"File's Universally Unique "
    "Identifier (RFC "
    "4122)\",\"type\":\"string\"},\"file_extension\":{\"description\":\"Sample block "
    "file extension, without the leading "
    "dot\",\"type\":\"string\"}}},\"range_offset_m\":{\"description\":\"Calibrated "
    "device specific range offset for waveform analysis by system response "
    "fitting in meters.\",\"type\":\"number\"}}}"
    ,
    /* example: */
    "{\"sample_data_files\":[{\"delta_st\":0,\"sample_interval\":1.00503e-09,\"cha"
    "nnel_name\":\"high_power\",\"file_uuid\":\"da084413-e3e8-4655-a122-071de8490"
    "d8e\",\"file_extension\":\"sp0\",\"sample_bits\":12,\"laser_wavelength\":0,\"cha"
    "nnel\":0},{\"delta_st\":0,\"sample_interval\":1.00503e-09,\"channel_name\":\"l"
    "ow_power\",\"file_uuid\":\"93585b5e-5ea9-43a1-947b-e7ba3be642d2\",\"file_ext"
    "ension\":\"sp1\",\"sample_bits\":12,\"laser_wavelength\":0,\"channel\":1},{\"del"
    "ta_st\":0,\"sample_interval\":1.00503e-09,\"channel_name\":\"wwf\",\"file_uuid"
    "\":\"9d2298c4-1036-464f-b5cb-1cf8e517f3a0\",\"file_extension\":\"sp5\",\"sampl"
    "e_bits\":12,\"laser_wavelength\":0,\"channel\":5}],\"sample_block_file\":{\"fi"
    "le_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"sbx\""
    "},\"range_offset_m\":3.1415,\"range_offset_waveform_samples_m \":7.283}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"items\":{\"required\":[\"sbl_name\",\"enabled\",\"channel_idx_mask\"],\"type\":"
    "\"object\",\"properties\":{\"pass_rng_greater\":{\"description\":\"Threshold "
    "for range greater than "
    "[m]\",\"type\":\"number\"},\"pass_ampl_greater\":{\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\",\"type\":\"number\"},\"pass_dev_greater\":{\"description\":\"Threshold "
    "for deviation greater than "
    "[1]\",\"type\":\"integer\"},\"enabled\":{\"description\":\"Waveform output "
    "enabled\",\"type\":\"boolean\"},\"pass_ampl_less\":{\"description\":\"Threshold "
    "for amplitude less than "
    "[dB]\",\"type\":\"number\"},\"pass_rng_less\":{\"description\":\"Threshold for "
    "range less than "
    "[m]\",\"type\":\"number\"},\"smart_enabled\":{\"description\":\"Smart waveform "
    "output "
    "enabled\",\"type\":\"boolean\"},\"channel_idx_mask\":{\"description\":\"Bit mask"
    " for channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\",\"type\":\"integer\"},\"logic_expression\":{\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\",\"type\":\"string\"},\"pass_dev_less\":{\"description\":\"Threshold for"
    " deviation less than "
    "[1]\",\"type\":\"integer\"},\"sbl_name\":{\"description\":\"Name of sample "
    "block, e.g.: wfm, wwf\",\"type\":\"string\"}}},\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"description\":\"Scanner settings for waveform "
    "output\",\"title\":\"Waveform Settings\",\"type\":\"array\"}"
    ,
    /* example: */
    "[{\"pass_rng_greater\":9.27,\"pass_ampl_greater\":1.0,\"enabled\":true,\"pass"
    "_ampl_less\":5.0,\"pass_rng_less\":13.11,\"smart_enabled\":true,\"channel_id"
    "x_mask\":11,\"sbl_name\":\"wfm\"},{\"channel_idx_mask\":32,\"enabled\":false,\"s"
    "bl_name\":\"wwf\"}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Window analysis data estimated from scandata and "
    "resulting filter parameters\",\"title\":\"Window Analysis\",\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\",\"required\":[\"result\",\"filter\",\"se"
    "ttings\"],\"type\":\"object\",\"properties\":{\"filter\":{\"required\":[\"angle\",\""
    "range_min\",\"range_max\",\"amplitude_max\"],\"type\":\"object\",\"properties\":{"
    "\"angle\":{\"description\":\"[deg]\",\"items\":{\"type\":\"number\"},\"type\":\"array"
    "\"},\"amplitude_max\":{\"description\":\"[dB]\",\"items\":{\"type\":\"number\"},\"ty"
    "pe\":\"array\"},\"range_min\":{\"description\":\"[m]\",\"items\":{\"type\":\"number\""
    "},\"type\":\"array\"},\"range_max\":{\"description\":\"[m]\",\"items\":{\"type\":\"nu"
    "mber\"},\"type\":\"array\"}}},\"settings\":{\"required\":[\"range\",\"amplitude\"],"
    "\"type\":\"object\",\"properties\":{\"amplitude\":{\"required\":[\"sigma_factor\","
    "\"additive_value\"],\"type\":\"object\",\"properties\":{\"additive_value\":{\"typ"
    "e\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}}},\"range\":{\"required\":[\""
    "sigma_factor\",\"additive_value\"],\"type\":\"object\",\"properties\":{\"additiv"
    "e_value\":{\"type\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}}}}},\"resul"
    "t\":{\"required\":[\"angle\",\"range_mean\",\"range_sigma\",\"amplitude_mean\",\"a"
    "mplitude_sigma\",\"amplitude_offset\"],\"type\":\"object\",\"properties\":{\"amp"
    "litude_sigma\":{\"description\":\"[dB]\",\"items\":{\"type\":\"number\"},\"type\":\""
    "array\"},\"range_sigma\":{\"description\":\"[m]\",\"items\":{\"type\":\"number\"},\""
    "type\":\"array\"},\"timestamp\":{\"description\":\"[s]\",\"items\":{\"type\":\"numbe"
    "r\"},\"type\":\"array\"},\"range_mean\":{\"description\":\"[m]\",\"items\":{\"type\":"
    "\"number\"},\"type\":\"array\"},\"amplitude_offset\":{\"description\":\"[dB]\",\"it"
    "ems\":{\"type\":\"number\"},\"type\":\"array\"},\"angle\":{\"description\":\"[deg]\","
    "\"items\":{\"type\":\"number\"},\"type\":\"array\"},\"amplitude_mean\":{\"descripti"
    "on\":\"[dB]\",\"items\":{\"type\":\"number\"},\"type\":\"array\"}}}}}"
    ,
    /* example: */
    "{\"filter\":{\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,"
    "15.9],\"amplitude_max\":[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7.8"
    ",7.78],\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0"
    ".221,-0.223,-0.225,-0.227],\"range_max\":[0.424,0.425,0.426,0.427,0.428,"
    "0.428,0.429,0.43,0.431,0.431,0.432]},\"settings\":{\"amplitude\":{\"additiv"
    "e_value\":1.0,\"sigma_factor\":4},\"range\":{\"additive_value\":0.1,\"sigma_fa"
    "ctor\":8}},\"result\":{\"amplitude_sigma\":[0.4272844,0.4298479,0.4236816,0"
    ".4283583,0.4362353,0.4315141,0.4373984,0.4472798,0.4346001,0.4345487,0"
    ".4540681],\"range_sigma\":[0.01869652,0.02151435,0.01747969,0.01918765,0"
    ".01945776,0.01934862,0.01955329,0.02225589,0.02229977,0.01899122,0.020"
    "09433],\"timestamp\":[408.4441,411.4443],\"range_mean\":[0.1105621,0.10795"
    "64,0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.105152"
    "3,0.1058445,0.1031261],\"amplitude_offset\":[1.9,1.9],\"angle\":[14.9,15.0"
    ",15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],\"amplitude_mean\":[5.347"
    "396,5.263155,5.224655,5.179926,5.097782,5.116479,5.051756,4.983473,5.0"
    "07885,5.002441,4.982]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"description\":\"Correction parameters for window glass "
    "echoes\",\"title\":\"Window Echo Correction\",\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"required\":[\"amplitude\",\"range\",\"slices\"],\"type"
    "\":\"object\",\"properties\":{\"amplitude\":{\"required\":[\"minimum\",\"maximum\","
    "\"entries\"],\"description\":\"Amplitude axis of correction table\",\"type\":\""
    "object\",\"properties\":{\"entries\":{\"minimum\":1,\"description\":\"Number of "
    "amplitude entries\",\"type\":\"integer\"},\"minimum\":{\"minimum\":0.0,\"descrip"
    "tion\":\"Minimum amplitude in "
    "dB\",\"type\":\"number\"},\"maximum\":{\"minimum\":0.0,\"description\":\"Maximum "
    "amplitude in dB\",\"type\":\"number\"}}},\"slices\":{\"items\":{\"required\":[\"am"
    "plitude\",\"table\"],\"description\":\"Window echo correction parameter slic"
    "e\",\"type\":\"object\",\"properties\":{\"table\":{\"items\":{\"items\":{\"items\":{\""
    "description\":\"Table cell (item 0: amplitude in dB, 1: range in m, 2: "
    "flags)\",\"type\":\"number\"},\"maxItems\":3,\"description\":\"Table column (= "
    "range axis)\",\"type\":\"array\",\"minItems\":3},\"description\":\"Table row (= "
    "amplitude "
    "axis)\",\"type\":\"array\",\"minItems\":1},\"description\":\"Correction table "
    "(dimension defined by the 'amplitude' and 'range' objects)\",\"type\":\"ar"
    "ray\",\"minItems\":1},\"amplitude\":{\"description\":\"Window echo amplitude "
    "of slice in dB\",\"type\":\"number\"}}},\"type\":\"array\"},\"range\":{\"required\""
    ":[\"minimum\",\"maximum\",\"entries\"],\"description\":\"Range axis of "
    "correction table\",\"type\":\"object\",\"properties\":{\"entries\":{\"minimum\":1"
    ",\"description\":\"Number of range entries\",\"type\":\"integer\"},\"minimum\":{"
    "\"minimum\":-2.0,\"description\":\"Minimum range in m\",\"type\":\"number\",\"max"
    "imum\":2.0},\"maximum\":{\"minimum\":-2.0,\"description\":\"Maximum range in "
    "m\",\"type\":\"number\",\"maximum\":2.0}}}}}"
    ,
    /* example: */
    "{\"amplitude\":{\"entries\":128,\"minimum\":2,\"maximum\":20},\"slices\":[{\"tabl"
    "e\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":1.5},{\"table\":[["
    "[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":2.0}],\"range\":{\"entri"
    "es\":128,\"minimum\":-1.5060822940732335,\"maximum\":1.5060822940732335}}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);

#endif // RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
